@@ -24,9 +24,9 @@ import hashlib
 import os
 import shutil
 import tempfile
+import pytest
 import unittest
 from unittest import skipUnless
-from nose import SkipTest
 from nose.tools import eq_, ok_     # pylint: disable=E0611
 from .. testutils import GbpLogTester
 
@@ -66,19 +66,19 @@ class ComponentTestGitRepository(GitRepository):
         try:
             repo = cls('.')
         except GitRepositoryError:
-            raise SkipTest("Skipping '%s', since this is not a git checkout."
-                           % __name__)
+            pytest.skip("Skipping '%s', since this is not a git checkout."
+                        % __name__)
 
         submodules = repo.submodule_status()
         try:
             status = submodules[data]
         except KeyError:
-            raise SkipTest("Skipping '%s', testdata directory not a known "
-                           "submodule." % __name__)
+            pytest.skip("Skipping '%s', testdata directory not a known "
+                        "submodule." % __name__)
 
         if status[0] == '-':
-            raise SkipTest("Skipping '%s', testdata directory not initialized. "
-                           "Consider doing 'git submodule update'" % __name__)
+            pytest.skip("Skipping '%s', testdata directory not initialized. "
+                        "Consider doing 'git submodule update'" % __name__)
 
     def ls_tree(self, treeish):
         """List contents (blobs) in a git treeish"""
