@@ -33,7 +33,7 @@ def teardown_module():
     context.teardown()
 
 
-def test_create():
+def test_repo():
     """
     Create a repository
 
@@ -44,7 +44,8 @@ def test_create():
          - L{gbp.git.GitRepository.path}
          - L{gbp.git.GitRepository.git_dir}
 
-    >>> import os, gbp.git
+    >>> setup_module()
+    >>> import shutil, os, gbp.git
     >>> repo = gbp.git.GitRepository.create(dirs['repo'])
     >>> repo.path == dirs['repo']
     True
@@ -52,30 +53,15 @@ def test_create():
     True
     >>> type(repo) == gbp.git.GitRepository
     True
-    """
-
-
-def test_empty():
-    """
-    Empty repos have no branch
-
-    Methods tested:
-         - L{gbp.git.GitRepository.get_branch}
-         - L{gbp.git.GitRepository.is_empty}
-
-    >>> import gbp.git
+    >>> # test_empty()
+    >>> # Empty repos have no branch
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.get_branch()
     >>> repo.branch
     >>> repo.is_empty()
     True
-    """
-
-
-def test_subdir():
-    """
-    Make surewe can init repos from a subdir
-    >>> import gbp.git, os
+    >>> # test_subdir()
+    >>> # Make sure we can init repos from a subdir
     >>> os.mkdir(os.path.join(dirs['repo'], 'subdir'))
     >>> repo = gbp.git.GitRepository(os.path.join(dirs['repo'], 'subdir'), toplevel=False)
     >>> repo.path == dirs['repo']
@@ -84,22 +70,8 @@ def test_subdir():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Not the toplevel of a Git repository at ...
-    """
-
-
-def test_add_files():
-    """
-    Add some dummy data
-
-    Methods tested:
-         - L{gbp.git.GitRepository.add_files}
-         - L{gbp.git.GitRepository.commit_all}
-         - L{gbp.git.GitRepository.is_clean}
-
-    Properties tested:
-         - L{gbp.git.GitRepository.head}
-
-    >>> import gbp.git, shutil, os
+    >>> # test_add_files:
+    >>> # Add some dummy data
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"),
     ...                                os.path.join(repo.path, "testfile"))
@@ -120,15 +92,7 @@ def test_add_files():
     >>> h = repo.head
     >>> len(h)
     40
-    """
-
-
-def test_rename_file():
-    """
-    Methods tested:
-         - L{gbp.git.GitRepository.rename_file}
-
-    >>> import gbp.git
+    >>> # test_rename_file:
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.rename_file("testfile", "testfile2")
     >>> repo.rename_file("testfile2", "testfile")
@@ -136,32 +100,15 @@ def test_rename_file():
     Traceback (most recent call last):
     ...
     gbp.errors.GbpError: Failed to move 'doesnotexit' to 'testfile2': fatal: bad source, source=doesnotexit, destination=testfile2
-    """
-
-
-def test_branch_master():
-    """
-    First branch is called I{master}
-
-    Methods tested:
-         - L{gbp.git.GitRepository.get_branch}
-    >>> import gbp.git, shutil
+    >>> # test_branch_master:
+    >>> # First branch is called I{master}
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.get_branch()
     'master'
     >>> repo.branch
     'master'
-    """
-
-
-def test_clean():
-    """
-    Remove untracked files from the working tree
-
-    Methods tested:
-         - L{gbp.git.GitRepository.clean}
-
-    >>> import gbp.git, shutil, os
+    >>> # test_clean:
+    >>> # Remove untracked files from the working tree
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"),
     ...                                os.path.join(repo.path, "testclean"))
@@ -171,36 +118,16 @@ def test_clean():
     >>> repo.clean(directories=True, force=True)
     >>> repo.is_clean()[0]
     True
-    """
-
-
-def test_create_branch():
-    """
-    Create a branch name I{foo}
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create_branch}
-         - L{gbp.git.GitRepository.branch_contains}
-
-    >>> import gbp.git, shutil
+    >>> # test_create_branch:
+    >>> # Create a branch name I{foo}
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.create_branch("foo")
     >>> repo.branch_contains("foo", 'HEAD')
     True
     >>> repo.branch_contains("doesnotexist", 'HEAD', remote=True)
     False
-    """
-
-
-def test_delete_branch():
-    """
-    Create a branch named I{foo2} and delete it
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create_branch}
-         - L{gbp.git.GitRepository.delete_branch}
-
-    >>> import gbp.git, shutil
+    >>> # test_delete_branch:
+    >>> # Create a branch named I{foo2} and delete it
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.create_branch("bar")
     >>> repo.delete_branch("bar")
@@ -208,51 +135,22 @@ def test_delete_branch():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Can't delete the branch you're on
-    """
-
-
-def test_set_branch():
-    """
-    Switch to branch named I{foo}
-
-    Methods tested:
-         - L{gbp.git.GitRepository.set_branch}
-         - L{gbp.git.GitRepository.get_branch}
-         - L{gbp.git.GitRepository.branch}
-
-    >>> import gbp.git
+    >>> # test_set_branch:
+    >>> # Switch to branch named I{foo}
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch("foo")
     >>> repo.get_branch() == "foo"
     True
     >>> repo.branch == "foo"
     True
-    """
-
-
-def test_rename_branch():
-    """
-    Create branch named I{baz}, rename it to I{bax} and finally delete it
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create_branch}
-         - L{gbp.git.GitRepository.rename_branch}
-         - L{gbp.git.GitRepository.delete_branch}
-
-    >>> import gbp.git
+    >>> # test_rename_branch:
+    >>> # Create branch named I{baz}, rename it to I{bax} and finally delete it
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.create_branch("baz")
     >>> repo.rename_branch("baz", "bax")
     >>> repo.delete_branch("bax")
-    """
-
-
-def test_set_upstream_branch():
-    """
-    Set upstream branch master -> origin/master
-
-    >>> import os, shutil
-    >>> import gbp.git
+    >>> # test_set_upstream_branch
+    >>> # Set upstream branch master -> origin/master
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> os.makedirs(os.path.join(repo.git_dir, 'refs/remotes/origin'))
     >>> ret = shutil.copy(os.path.join(repo.git_dir, 'refs/heads/master'), \
@@ -267,14 +165,8 @@ def test_set_upstream_branch():
     >>> repo.set_upstream_branch('foo', 'origin/bla')
     Traceback (most recent call last):
     gbp.git.repository.GitRepositoryError: Branch origin/bla doesn't exist!
-    """
-
-
-def test_get_upstream_branch():
-    """
-    Get info about upstream branches set in test_set_upstream_branch
-
-    >>> import gbp.git
+    >>> # test_get_upstream_branch():
+    >>> # Get info about upstream branches set in test_set_upstream_branch
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.get_upstream_branch('master')
     'origin/master'
@@ -283,20 +175,8 @@ def test_get_upstream_branch():
     >>> repo.get_upstream_branch('bla')
     Traceback (most recent call last):
     gbp.git.repository.GitRepositoryError: Branch bla doesn't exist!
-    """
-
-
-def test_tag():
-    """
-    Create a tag named I{tag} and check its existence
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create_tag}
-         - L{gbp.git.GitRepository.verify_tag}
-         - L{gbp.git.GitRepository.has_tag}
-         - L{gbp.git.GitRepository.get_tags}
-
-    >>> import gbp.git
+    >>> # test_tag():
+    >>> # Create a tag named I{tag} and check its existence
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.create_tag("tag")
     >>> repo.has_tag("tag")
@@ -312,17 +192,8 @@ def test_tag():
     ['tag', 'tag2']
     >>> repo.tags
     ['tag', 'tag2']
-    """
-
-
-def test_describe():
-    """
-    Describe commit-ish
-
-    Methods tested:
-         - L{gbp.git.GitRepository.describe}
-
-    >>> import gbp.git
+    >>> # test_describe():
+    >>> # Describe commit-ish
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> sha = repo.rev_parse('HEAD')
     >>> repo.describe('HEAD')
@@ -346,17 +217,8 @@ def test_describe():
     >>> repo.describe('HEAD', tags=True, exact_match=True)
     'tag'
     >>> repo.create_tag('tag2', msg='foo')
-    """
-
-
-def test_find_tag():
-    """
-    Find tags
-
-    Methods tested:
-         - L{gbp.git.GitRepository.find_tag}
-
-    >>> import gbp.git
+    >>> # test_find_tag():
+    >>> # Find tags
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.find_tag('HEAD')
     'tag2'
@@ -364,17 +226,8 @@ def test_find_tag():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Can't describe HEAD. Git error: fatal: No names found, cannot describe anything.
-    """
-
-
-def test_find_branch_tag():
-    """
-    Find the closest tags on a certain branch to a given commit
-
-    Methods tested:
-         - L{gbp.git.GitRepository.find_branch_tag}
-
-    >>> import gbp.git
+    >>> # test_find_branch_tag():
+    >>> # Find the closest tags on a certain branch to a given commit
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.find_branch_tag('HEAD', 'master', 'tag*')
     'tag2'
@@ -382,55 +235,24 @@ def test_find_branch_tag():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Can't describe .... Git error: fatal: No names found, cannot describe anything.
-    """
-
-
-def test_move_tag():
-    """
-    Move a tag
-
-    Methods tested:
-         - L{gbp.git.GitRepository.move_tag}
-         - L{gbp.git.GitRepository.has_tag}
-
-    >>> import gbp.git
+    >>> # test_move_tag():
+    >>> # Move a tag
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.move_tag("tag", "moved")
     >>> repo.has_tag("tag")
     False
     >>> repo.has_tag("moved")
     True
-    """
-
-
-def test_delete_tag():
-    """
-    Delete tags
-
-    Methods tested:
-         - L{gbp.git.GitRepository.delete_tag}
-         - L{gbp.git.GitRepository.has_tag}
-
-    >>> import gbp.git
+    >>> # test_delete_tag():
+    >>> # Delete tags
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.has_tag("moved")
     True
     >>> repo.delete_tag("moved")
     >>> repo.has_tag("moved")
     False
-    """
-
-
-def test_get_obj_type():
-    """
-    Find commit SHA1 related to tags
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create_tag}
-         - L{gbp.git.GitRepository.get_obj_type}
-         - L{gbp.git.GitRepository.delete_tag}
-
-    >>> import gbp.git
+    >>> # test_get_obj_type():
+    >>> # Find commit SHA1 related to tags
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.create_tag("tag3", "tag msg")
     >>> repo.get_obj_type("tag3")
@@ -440,21 +262,8 @@ def test_get_obj_type():
     >>> repo.get_obj_type("HEAD:testfile")
     'blob'
     >>> repo.delete_tag("tag3")
-    """
-
-
-def test_list_files():
-    """
-    List files in the index
-
-    Methods tested:
-         - L{gbp.git.GitRepository.list_files}
-         - L{gbp.git.GitRepository.add_files}
-         - L{gbp.git.GitRepository.commit_staged}
-         - L{gbp.git.GitRepository.commit_files}
-         - L{gbp.git.GitRepository.force_head}
-
-    >>> import gbp.git, os, shutil
+    >>> # test_list_files():
+    >>> # List files in the index
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> src = os.path.join(repo.path, ".git/HEAD")
     >>> dst = os.path.join(repo.path, "testfile")
@@ -486,17 +295,8 @@ def test_list_files():
     >>> repo.commit_files(dst, msg="foo")
     >>> repo.list_files(['modified'])
     []
-    """
-
-
-def test_get_commits():
-    """
-    Test listing commits
-
-    Methods tested:
-         - L{gbp.git.GitRepository.get_commits}
-
-    >>> import gbp.git
+    >>> # test_get_commits():
+    >>> # Test listing commits
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> commits = repo.get_commits()
     >>> type(commits) == list and len(commits) == 2
@@ -517,17 +317,8 @@ def test_get_commits():
     []
     >>> repo.get_commits(paths=['testfile']) == commits
     True
-    """
-
-
-def test_get_commit_info():
-    """
-    Test inspecting commits
-
-    Methods tested:
-         - L{gbp.git.GitRepository.get_commit_info}
-
-    >>> import gbp.git
+    >>> # test_get_commit_info():
+    >>> # Test inspecting commits
     >>> from datetime import datetime
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> info = repo.get_commit_info('HEAD')
@@ -552,17 +343,8 @@ def test_get_commit_info():
     defaultdict(<class 'list'>, {'M': [b'testfile']})
     >>> repo.get_subject('HEAD')
     'foo'
-    """
-
-
-def test_diff():
-    """
-    Test git-diff
-
-    Methods tested:
-         - L{gbp.git.GitRepository.diff}
-
-    >>> import gbp.git
+    >>> # test_diff():
+    >>> # Test git-diff
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> len(repo.diff('HEAD~1', 'HEAD')) > 3
     True
@@ -574,35 +356,14 @@ def test_diff():
     True
     >>> repo.diff('HEAD~1', 'HEAD') == repo.diff('HEAD~1')
     True
-    """
-
-
-def test_diff_status():
-    """
-    Methods tested:
-        - L{gbp.git.GitRepository.diff_status}
-
-    >>> import gbp.git
+    >>> # test_diff_status():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.diff_status("HEAD", "HEAD")
     defaultdict(<class 'list'>, {})
     >>> repo.diff_status("HEAD~1", "HEAD")
     defaultdict(<class 'list'>, {'M': [b'testfile']})
-    """
-
-
-def test_mirror_clone():
-    """
-    Mirror a repository
-
-    Methods tested:
-         - L{gbp.git.GitRepository.clone}
-         - L{gbp.git.GitRepository.is_empty}
-         - L{gbp.git.GitRepository.set_branch}
-         - L{gbp.git.GitRepository.has_branch}
-         - L{gbp.git.GitRepository.branch}
-
-    >>> import gbp.git
+    >>> # test_mirror_clone():
+    >>> # Mirror a repository
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch('master')
     >>> repo.branch
@@ -620,25 +381,8 @@ def test_mirror_clone():
     >>> mirror.branch
     'foo'
     >>> mirror.force_head('foo^')
-    """
-
-
-def test_clone():
-    """
-    Clone a repository
-
-    Methods tested:
-         - L{gbp.git.GitRepository.clone}
-         - L{gbp.git.GitRepository.is_empty}
-         - L{gbp.git.GitRepository.set_branch}
-         - L{gbp.git.GitRepository.branch}
-         - L{gbp.git.GitRepository.get_merge_branch}
-         - L{gbp.git.GitRepository.get_remote_branches}
-         - L{gbp.git.GitRepository.get_local_branches}
-         - L{gbp.git.GitRepository.get_remote_repos}
-         - L{gbp.git.GitRepository.has_remote_repo}
-
-    >>> import gbp.git
+    >>> # test_clone():
+    >>> # Clone a repository
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch('master')
     >>> clone = gbp.git.GitRepository.clone(dirs['clone'], repo.path)
@@ -667,18 +411,8 @@ def test_clone():
     True
     >>> clone.has_remote_repo('godiug')
     False
-    """
-
-
-def test_get_remotes():
-    """
-    Check remotes
-
-    Methods tested:
-         - L{gbp.git.GitRepository.get_remotes}
-
-    >>> import os
-    >>> import gbp.git.repository
+    >>> # test_get_remotes():
+    >>> # Check remotes
     >>> repo = gbp.git.repository.GitRepository(os.path.join(dirs['clone'], 'repo'))
     >>> remotes = repo.get_remotes()
     >>> len(remotes)
@@ -690,56 +424,23 @@ def test_get_remotes():
     True
     >>> origin.push_urls == [dirs['repo']]
     True
-    """
-
-
-def test_merge():
-    """
-    Merge a branch
-
-    Methods tested:
-         - L{gbp.git.GitRepository.merge}
-         - L{gbp.git.GitRepository.set_branch}
-
-    >>> import gbp.git
+    >>> # test_merge():
+    >>> # Merge a branch
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch('master')
     >>> repo.merge('foo')
     >>> repo.is_in_merge()
     False
-    """
-
-
-def test_pull():
-    """
-    Pull from a remote repository
-
-    Methods tested:
-         - L{gbp.git.GitRepository.set_branch}
-         - L{gbp.git.GitRepository.pull}
-
-    >>> import gbp.git, os
+    >>> # test_pull():
+    >>> # Pull from a remote repository
     >>> d = os.path.join(dirs['clone'], 'repo')
     >>> clone = gbp.git.GitRepository(d)
     >>> clone.set_branch('master')
     >>> clone.pull()
     >>> clone.pull(all_remotes=True)
     >>> clone.pull('origin', all_remotes=True)
-    """
-
-
-def test_fetch():
-    """
-    Fetch from a remote repository
-
-    Methods tested:
-         - L{gbp.git.GitRepository.fetch}
-         - L{gbp.git.GitRepository.push}
-         - L{gbp.git.GitRepository.push_tag}
-         - L{gbp.git.GitRepository.add_remote_repo}
-         - L{gbp.git.GitRepository.remove_remote_repo}
-
-    >>> import gbp.git, os
+    >>> # test_fetch():
+    >>> # Fetch from a remote repository
     >>> d = os.path.join(dirs['clone'], 'repo')
     >>> clone = gbp.git.GitRepository(d)
     >>> clone.fetch()
@@ -759,18 +460,8 @@ def test_fetch():
     >>> clone.fetch('foo', refspec='refs/heads/master')
     >>> clone.fetch(all_remotes=True)
     >>> clone.remove_remote_repo('foo')
-    """
-
-
-def test_create_bare():
-    """
-    Create a bare repository
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create}
-         - L{gbp.git.GitRepository.is_empty}
-
-    >>> import gbp.git
+    >>> # test_create_bare():
+    >>> # Create a bare repository
     >>> bare = gbp.git.GitRepository.create(dirs['bare'], bare=True, description="msg")
     >>> bare.path == dirs['bare']
     True
@@ -782,54 +473,20 @@ def test_create_bare():
     True
     >>> bare.is_clean()
     (True, '')
-    """
-
-
-def test_nonexistent():
-    """
-    Check that accessing a non-existent repository fails.
-
-    Methods tested:
-         - L{gbp.git.GitRepository.__init__}
-
-    >>> import gbp.git
+    >>> # test_nonexistent():
+    >>> # Check that accessing a non-existent repository fails.
     >>> bare = gbp.git.GitRepository("/does/not/exist")
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: No Git repository at '/does/not/exist'
-    """
-
-
-def test_create_noperm():
-    """
-    Check that creating a repository at a path that isn't writeable fails
-
-    Methods tested:
-         - L{gbp.git.GitRepository.create}
-
-    >>> import gbp.git
+    >>> # test_create_noperm():
+    >>> # Check that creating a repository at a path that isn't writeable fails
     >>> gbp.git.GitRepository.create("/does/not/exist")
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Cannot create Git repository at '/does/not/exist': [Errno 13] Permission denied: '/does'
-    """
-
-
-def test_checkout():
-    """
-    Checkout treeishs
-
-    Methods tested:
-         - L{gbp.git.GitRepository.checkout}
-         - L{gbp.git.GitRepository.get_branch}
-         - L{gbp.git.GitRepository.set_branch}
-         - L{gbp.git.GitRepository.rev_parse}
-
-    Properties tested:
-         - L{gbp.git.GitRepository.branch}
-         - L{gbp.git.GitRepository.tags}
-
-    >>> import gbp.git
+    >>> # test_checkout():
+    >>> # Checkout treeishs
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.checkout('master')
     >>> repo.branch
@@ -853,32 +510,14 @@ def test_checkout():
     >>> tag = repo.tags[0]
     >>> repo.checkout(tag)
     >>> repo.branch
-    """
-
-
-def test_gc():
-    """
-    Test garbage collection
-
-    Methods tested:
-         - L{gbp.git.GitRepository.collect_garbage}
-
-    >>> import gbp.git
+    >>> # test_gc():
+    >>> # Test garbage collection
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.collect_garbage()
     >>> repo.collect_garbage(prune=True)
     >>> repo.collect_garbage(prune='all', aggressive=True)
-    """
-
-
-def test_grep_log():
-    """
-    Test grepping through commit messages
-
-    Methods tested:
-        - L{gbp.git.GitRepository.grep_log}
-
-    >>> import gbp.git
+    >>> # test_grep_log():
+    >>> # Test grepping through commit messages
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_branch('master')
     >>> len(repo.grep_log('foo')) == 2
@@ -891,17 +530,8 @@ def test_grep_log():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Error grepping log for foo: fatal: bad revision 'doesnotexist'
-    """
-
-
-def test_is_ff():
-    """
-    Test if branch is fast forwardable
-
-    Methods tested:
-        - L{gbp.git.GitRepository.is_fast_forward}
-
-    >>> import gbp.git
+    >>> # test_is_ff():
+    >>> # Test if branch is fast forwardable
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.is_fast_forward('master', 'foo')
     (True, True)
@@ -910,34 +540,14 @@ def test_is_ff():
     (True, False)
     >>> repo.is_fast_forward('master', 'ff')
     (False, True)
-    """
-
-
-def test_update_ref():
-    """
-    Test updating a reference
-
-    Methods tested:
-        - L{gbp.git.GitRepository.update_ref}
-
-    >>> import gbp.git, os
+    >>> # test_update_ref():
+    >>> # Test updating a reference
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.update_ref('new_ref', 'master', msg='update')
     >>> os.path.exists(os.path.join(repo.git_dir, 'new_ref'))
     True
-    """
-
-
-def test_make_tree():
-    """
-    Test git-mk-tree
-
-    Methods tested:
-        - L{gbp.git.GitRepository.write_file}
-        - L{gbp.git.GitRepository.list_tree}
-        - L{gbp.git.GitRepository.make_tree}
-
-    >>> import gbp.git
+    >>> # test_make_tree():
+    >>> # Test git-mk-tree
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> sha1 = repo.write_file('testfile')
     >>> sha1
@@ -955,33 +565,14 @@ def test_make_tree():
     [('100644', 'blob', '19af7398c894bc5e86e17259317e4db519e9241f', 20, b'testfile')]
     >>> repo.make_tree([])
     '4b825dc642cb6eb9a060e54bf8d69288fbee4904'
-    """
-
-
-def test_update_submodules():
-    """
-    Updating submodules if we don't have any is a noop
-
-    Methods tested:
-        - L{gbp.git.GitRepository.has_submodules}
-        - L{gbp.git.GitRepository.update_submodules}
-
-    >>> import gbp.git
+    >>> # test_update_submodules():
+    >>> # Updating submodules if we don't have any is a noop
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.has_submodules()
     False
     >>> repo.update_submodules()
-    """
-
-
-def test_get_merge_base():
-    """
-    Find the common ancestor of two objects
-
-    Methods tested:
-        - L{gbp.git.GitRepository.get_merge_base}
-
-    >>> import gbp.git
+    >>> # test_get_merge_base():
+    >>> # Find the common ancestor of two objects
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> sha1 = repo.get_merge_base('master', 'foo')
     >>> len(sha1)
@@ -990,15 +581,7 @@ def test_get_merge_base():
     Traceback (most recent call last):
     ...
     gbp.git.repository.GitRepositoryError: Failed to get common ancestor: fatal: Not a valid object name doesnotexist
-    """
-
-
-def test_status():
-    r"""
-    Methods tested:
-        - L{gbp.git.GitRepository.status}
-
-    >>> import gbp.git, os, shutil
+    >>> # test_status():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> fname = os.path.join(repo.path, "test_status")
     >>> ret = shutil.copy(os.path.join(repo.path, ".git/HEAD"), fname)
@@ -1012,16 +595,8 @@ def test_status():
     >>> repo.commit_all(msg='added %s' % fname)
     >>> _ = repo._git_inout('mv', [fname, fname + 'new'])
     >>> list(repo.status().items())
-    [('R ', [b'test_status\x00test_statusnew'])]
-    """
-
-
-def test_cmd_has_feature():
-    r"""
-    Methods tested:
-        - L{gbp.git.GitRepository._cmd_has_feature}
-
-    >>> import gbp.git
+    [('R ', [b'test_status\\x00test_statusnew'])]
+    >>> # test_cmd_has_feature():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo._cmd_has_feature("commit", "a")
     True
@@ -1043,47 +618,23 @@ def test_cmd_has_feature():
     True
     >>> repo._cmd_has_feature("show", "no-standard-notes")
     True
-    """
-
-
-def test_set_user_name_and_email():
-    r"""
-    Methods tested:
-        - L{gbp.git.GitRepository.set_user_name}
-        - L{gbp.git.GitRepository.set_user_email}
-
-    >>> import gbp.git
+    >>> # test_set_user_name_and_email():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_user_name("Michael Stapelberg")
     >>> repo.set_user_email("stapelberg@test.invalid")
-    """
-
-
-def test_set_config_and_get_config():
-    r"""
-    Methods tested:
-        - L{gbp.git.GitRepository.set_config}
-        - L{gbp.git.GitRepository.get_config}
-
-    >>> import gbp.git
+    >>> # test_set_config_and_get_config():
     >>> repo = gbp.git.GitRepository(dirs['repo'])
     >>> repo.set_config("user.email", "foo@example.com")
     >>> repo.get_config("user.email")
     'foo@example.com'
-    """
-
-
-def test_git_dir():
-    """
-    Properties tested:
-        - L{gbp.git.GitRepository.git_dir}
-    >>> import os, gbp.git
+    >>> # test_git_dir():
     >>> git_dir = os.path.join(dirs['repo'], '.git')
     >>> os.environ['GIT_DIR'] = git_dir
     >>> somewhere = gbp.git.GitRepository(os.path.join(dirs['repo'], '..'))
     >>> somewhere.git_dir == git_dir
     True
     >>> del os.environ['GIT_DIR']
+    >>> teardown_module()
     """
 
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
